summaryrefslogtreecommitdiffstats
path: root/mountconfig/fuser.py
diff options
context:
space:
mode:
Diffstat (limited to 'mountconfig/fuser.py')
-rw-r--r--mountconfig/fuser.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/mountconfig/fuser.py b/mountconfig/fuser.py
index 9bc54c9..4a10ca9 100644
--- a/mountconfig/fuser.py
+++ b/mountconfig/fuser.py
@@ -17,7 +17,7 @@
"""
TODO:
- Fix running standalone:
- * KCmdLineArgs stuff.
+ * TDECmdLineArgs stuff.
"""
import sys
@@ -278,14 +278,14 @@ if standalone:
device = "/dev/hda1"
print 'Device is ', device
- cmd_args = KCmdLineArgs.init(sys.argv, "FUser",
+ cmd_args = TDECmdLineArgs.init(sys.argv, "FUser",
"A graphical frontend to fuser, but without using it :-)", "0.2")
# ----------------------------------------------------------------------------
# FIXME: All the arg-parsing stuff does not work yet since I don't understand KCmdLineArgs.
options = [("device <device>", "Device to umount")]
- KCmdLineArgs.addCmdLineOptions(options)
- args = KCmdLineArgs.parsedArgs()
+ TDECmdLineArgs.addCmdLineOptions(options)
+ args = TDECmdLineArgs.parsedArgs()
# print args.count()
# ----------------------------------------------------------------------------
@@ -278,14 +278,14 @@ if standalone:
"A graphical frontend to fuser, but without using it :-)", "0.2")
# ----------------------------------------------------------------------------
- # FIXME: All the arg-parsing stuff does not work yet since I don't understand KCmdLineArgs.
+ # FIXME: All the arg-parsing stuff does not work yet since I don't understand TDECmdLineArgs.
options = [("device <device>", "Device to umount")]